"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_ipam_config import NetworkIPAMConfig
from pensando_dss.psm.model.network_orchestrator_info import NetworkOrchestratorInfo
from pensando_dss.psm.model.network_rd_spec import NetworkRDSpec
globals()['NetworkIPAMConfig'] = NetworkIPAMConfig
globals()['NetworkOrchestratorInfo'] = NetworkOrchestratorInfo
globals()['NetworkRDSpec'] = NetworkRDSpec
from pensando_dss.psm.psm.model.network_network_spec import NetworkNetworkSpec


class TestNetworkNetworkSpec(unittest.TestCase):
    """NetworkNetworkSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkSpec(self):
        """Test NetworkNetworkSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.search_v1_api import SearchV1Api  # noqa: E501


class TestSearchV1Api(unittest.TestCase):
    """SearchV1Api unit test stubs"""

    def setUp(self):
        self.api = SearchV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_policy_query1(self):
        """Test case for get_policy_query1

        Security Policy Query  # noqa: E501
        """
        pass

    def test_get_query1(self):
        """Test case for get_query1

        Structured or free-form search  # noqa: E501
        """
        pass

    def test_post_policy_query(self):
        """Test case for post_policy_query

        Security Policy Query  # noqa: E501
        """
        pass

    def test_post_query(self):
        """Test case for post_query

        Structured or free-form search  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.distributedservicecards_v1_api import DistributedservicecardsV1Api  # noqa: E501


class TestDistributedservicecardsV1Api(unittest.TestCase):
    """DistributedservicecardsV1Api unit test stubs"""

    def setUp(self):
        self.api = DistributedservicecardsV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_query_connection(self):
        """Test case for post_query_connection

        Active Connection Query  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
